# django-pluralize-ru

`django-pluralize-ru` — это фильтр для Django-шаблонов,
который позволяет склонять русские слова после числительных. Этот пакет полезен 
для корректного отображения числительных в русском языке в шаблонах Django.

## Установка

